@@ -7,7 +7,7 @@ from labstep.entities.collection.model import Collection
 from labstep.service.request import requestService
 from labstep.service.helpers import url_join, getHeaders
 from labstep.service.config import configService
-from labstep.generic.entity.repository import getEntities, editEntity, newEntity
+from labstep.generic.entity.repository import getEntities, editEntity, newEntities, newEntity
 from labstep.constants import UNSPECIFIED
 
 
@@ -18,8 +18,10 @@ def getCollections(
         "experiment": "experiment_workflow",
         "protocol": "protocol_collection",
         None: None,
+        UNSPECIFIED: UNSPECIFIED,
     }
-    params = {"search_query": search_query, "type": types[type], **extraParams}
+    params = {"search_query": search_query,
+              "type": types[type], 'group_id': user.activeWorkspace, **extraParams}
     return getEntities(user, Collection, count, params)
 
 
@@ -39,6 +41,14 @@ def newCollection(user, name, type, extraParams={}):
     return newEntity(user, Collection, params)
 
 
+def newCollections(user, names, type, extraParams={}):
+    types = {"experiment": "experiment_workflow",
+             "protocol": "protocol_collection"}
+    params = [{"name": name, "type": types[type], "group_id": user.activeWorkspace, **extraParams}
+              for name in names]
+    return newEntities(user, Collection, params)
+
+
 def addToCollection(entity, collection_id):
     entityName = entity.__entityName__
 
