@@ -63,3 +63,30 @@ class JupyterInstance(Entity):
         return jupyterInstanceRepository.editJupyterInstance(
             self, endedAt=getTime()
         )
+
+    def edit(self, data=None, extraParams={}):
+        """
+        Edit an existing JupyterInstance.
+
+        Parameters
+        ----------
+        data (str)
+            JupyterNotebook ipyb JSON data.
+
+        Returns
+        -------
+        :class:`~labstep.entities.jupyterInstance.model.JupyterInstance`
+            An object representing the edited JupyterInstance.
+
+        Example
+        -------
+        ::
+
+            my_jupyterInstance = user.getJupyterInstance("872b3e7e-e21f-4403-9ef3-3650fe0d86ba")
+            my_jupyterInstance.edit(data='{test: 42}')
+        """
+        import labstep.entities.jupyterInstance.repository as jupyterInstanceRepository
+
+        return jupyterInstanceRepository.editJupyterInstance(
+            self, data=data
+        )
