@@ -7,6 +7,7 @@ from labstep.generic.entity.model import Entity
 from labstep.service.config import configService
 from labstep.service.helpers import url_join, getHeaders
 from labstep.service.request import requestService
+from labstep.constants import UNSPECIFIED
 
 
 class User(Entity):
@@ -24,8 +25,8 @@ class User(Entity):
     """
     __entityName__ = "user"
 
-    def __init__(self, user, adminUser=None):
-        self.__user__ = adminUser if adminUser is not None else self
+    def __init__(self, user, adminUser=UNSPECIFIED):
+        self.__user__ = adminUser if adminUser is not UNSPECIFIED else self
         if 'group' not in user or user["group"] is None:
             print(
                 """Warning: No default workspace.
@@ -336,11 +337,11 @@ class User(Entity):
     def getExperiments(
         self,
         count=100,
-        search_query=None,
-        created_at_from=None,
-        created_at_to=None,
-        tag_id=None,
-        collection_id=None,
+        search_query=UNSPECIFIED,
+        created_at_from=UNSPECIFIED,
+        created_at_to=UNSPECIFIED,
+        tag_id=UNSPECIFIED,
+        collection_id=UNSPECIFIED,
         extraParams={},
     ):
         """
@@ -395,11 +396,11 @@ class User(Entity):
     def getProtocols(
         self,
         count=100,
-        search_query=None,
-        created_at_from=None,
-        created_at_to=None,
-        tag_id=None,
-        collection_id=None,
+        search_query=UNSPECIFIED,
+        created_at_from=UNSPECIFIED,
+        created_at_to=UNSPECIFIED,
+        tag_id=UNSPECIFIED,
+        collection_id=UNSPECIFIED,
         extraParams={},
     ):
         """
@@ -451,7 +452,7 @@ class User(Entity):
             extraParams=extraParams,
         )
 
-    def getResources(self, count=100, search_query=None, tag_id=None, extraParams={}):
+    def getResources(self, count=100, search_query=UNSPECIFIED, tag_id=UNSPECIFIED, extraParams={}):
         """
         Retrieve a list of a User's Resources
         across all Workspaces on Labstep,
@@ -489,7 +490,7 @@ class User(Entity):
         )
 
     def getResourceCategorys(
-        self, count=100, search_query=None, tag_id=None, extraParams={}
+        self, count=100, search_query=UNSPECIFIED, tag_id=UNSPECIFIED, extraParams={}
     ):
         """
         Retrieve a list of a User's Resource Categorys
@@ -527,7 +528,7 @@ class User(Entity):
             extraParams=extraParams,
         )
 
-    def getResourceLocations(self, count=100, search_query=None, extraParams={}):
+    def getResourceLocations(self, count=100, search_query=UNSPECIFIED, extraParams={}):
         """
         Retrieve a list of a user's ResourceLocations on Labstep,
         which can be filtered using the parameters:
@@ -556,7 +557,7 @@ class User(Entity):
             self, count=count, search_query=search_query, extraParams=extraParams
         )
 
-    def getResourceItems(self, count=100, search_query=None, extraParams={}):
+    def getResourceItems(self, count=100, search_query=UNSPECIFIED, extraParams={}):
         """
         Retrieve a list of a user's ResourceItems on Labstep,
         which can be filtered using the parameters:
@@ -586,7 +587,7 @@ class User(Entity):
         )
 
     def getOrderRequests(
-        self, count=100, search_query=None, status=None, tag_id=None, extraParams={}
+        self, count=100, search_query=UNSPECIFIED, status=UNSPECIFIED, tag_id=UNSPECIFIED, extraParams={}
     ):
         """
         Retrieve a list of a user's OrderRequests on Labstep,
@@ -627,7 +628,7 @@ class User(Entity):
             extraParams=extraParams,
         )
 
-    def getTags(self, count=1000, search_query=None, type=None, extraParams={}):
+    def getTags(self, count=1000, search_query=UNSPECIFIED, type=UNSPECIFIED, extraParams={}):
         """
         Retrieve a list of a User's Tags
         across all Workspaces on Labstep,
@@ -665,7 +666,7 @@ class User(Entity):
             extraParams=extraParams,
         )
 
-    def getWorkspaces(self, count=100, search_query=None, extraParams={}):
+    def getWorkspaces(self, count=100, search_query=UNSPECIFIED, extraParams={}):
         """
         Retrieve a list of a user's Workspaces on Labstep,
         which can be filtered using the parameters:
@@ -696,10 +697,10 @@ class User(Entity):
         )
 
     @deprecated(version='3.0.3', reason="You should use workspace.getFiles instead")
-    def getFiles(self, count=100, search_query=None, file_type=None, extraParams={}):
+    def getFiles(self, count=100, search_query=UNSPECIFIED, file_type=UNSPECIFIED, extraParams={}):
         return []
 
-    def getDevices(self, count=100, search_query=None, extraParams={}):
+    def getDevices(self, count=100, search_query=UNSPECIFIED, extraParams={}):
         """
         Retrieve a list of a User's Devices
         across all Workspaces on Labstep,
@@ -731,7 +732,7 @@ class User(Entity):
 
     # newEntity()
 
-    def newExperiment(self, name, entry=None, extraParams={}):
+    def newExperiment(self, name, entry=UNSPECIFIED, extraParams={}):
         """
         Create a new Labstep Experiment.
 
@@ -783,7 +784,7 @@ class User(Entity):
 
         return protocolRepository.newProtocol(self, name, extraParams=extraParams)
 
-    def newResource(self, name, resource_category_id=None, extraParams={}):
+    def newResource(self, name, resource_category_id=UNSPECIFIED, extraParams={}):
         """
         Create a new Labstep Resource.
 
@@ -836,7 +837,7 @@ class User(Entity):
             self, name, extraParams=extraParams
         )
 
-    def newResourceLocation(self, name, outer_location_id=None, extraParams={}):
+    def newResourceLocation(self, name, outer_location_id=UNSPECIFIED, extraParams={}):
         """
         Create a new Labstep ResourceLocation.
 
@@ -951,7 +952,7 @@ class User(Entity):
 
         return workspaceRepository.newWorkspace(self, name, extraParams=extraParams)
 
-    def newFile(self, filepath=None, rawData=None, extraParams={}):
+    def newFile(self, filepath=UNSPECIFIED, rawData=UNSPECIFIED, extraParams={}):
         """
         Upload a file to the Labstep entity Data.
 
